@@ -48,6 +48,7 @@ class CampaignTestCase(unittest.TestCase):
     self.assertEquals(summary.Forwards, 11)
     self.assertEquals(summary.Likes, 32)
     self.assertEquals(summary.WebVersionURL, "http://createsend.com/t/r-3A433FC72FFE3B8B")
+    self.assertEquals(summary.WorldviewURL, "http://client.createsend.com/reports/wv/r/3A433FC72FFE3B8B")
 
   def test_lists_and_segments(self):
     self.campaign.stub_request("campaigns/%s/listsandsegments.json" % self.campaign_id, "campaign_listsandsegments.json")
@@ -83,6 +84,12 @@ class CampaignTestCase(unittest.TestCase):
     self.assertEquals(opens.Results[0].ListID, "512a3bc577a58fdf689c654329b50fa0")
     self.assertEquals(opens.Results[0].Date, "2010-10-11 08:29:00")
     self.assertEquals(opens.Results[0].IPAddress, "192.168.126.87")
+    self.assertEquals(opens.Results[0].Latitude, -33.8683)
+    self.assertEquals(opens.Results[0].Longitude, 151.2086)
+    self.assertEquals(opens.Results[0].City, "Sydney")
+    self.assertEquals(opens.Results[0].Region, "New South Wales")
+    self.assertEquals(opens.Results[0].CountryCode, "AU")
+    self.assertEquals(opens.Results[0].CountryName, "Australia")
     self.assertEquals(opens.ResultsOrderedBy, "date")
     self.assertEquals(opens.OrderDirection, "asc")
     self.assertEquals(opens.PageNumber, 1)
@@ -101,6 +108,12 @@ class CampaignTestCase(unittest.TestCase):
     self.assertEquals(clicks.Results[0].ListID, "512a3bc577a58fdf689c654329b50fa0")
     self.assertEquals(clicks.Results[0].Date, "2010-10-11 08:29:00")
     self.assertEquals(clicks.Results[0].IPAddress, "192.168.126.87")
+    self.assertEquals(clicks.Results[0].Latitude, -33.8683)
+    self.assertEquals(clicks.Results[0].Longitude, 151.2086)
+    self.assertEquals(clicks.Results[0].City, "Sydney")
+    self.assertEquals(clicks.Results[0].Region, "New South Wales")
+    self.assertEquals(clicks.Results[0].CountryCode, "AU")
+    self.assertEquals(clicks.Results[0].CountryName, "Australia")
     self.assertEquals(clicks.ResultsOrderedBy, "date")
     self.assertEquals(clicks.OrderDirection, "asc")
     self.assertEquals(clicks.PageNumber, 1)
