@@ -12,15 +12,28 @@ class ListTestCase(unittest.TestCase):
     self.list_id = "e3c5f034d68744f7881fdccf13c2daee"
     self.list = List(self.list_id)
 
-  def test_create(self):
+  def test_create_without_unsubscribe_setting(self):
     self.list.stub_request("lists/%s.json" % self.client_id, "create_list.json")
     list_id = self.list.create(self.client_id, "List One", "", False, "")
     self.assertEquals(list_id, "e3c5f034d68744f7881fdccf13c2daee")
 
-  def test_update(self):
+  def test_create_with_unsubscribe_setting(self):
+    self.list.stub_request("lists/%s.json" % self.client_id, "create_list.json")
+    list_id = self.list.create(self.client_id, "List One", "", False, "", "OnlyThisList")
+    self.assertEquals(list_id, "e3c5f034d68744f7881fdccf13c2daee")
+
+  def test_update_without_unsubscribe_setting(self):
     self.list.stub_request("lists/%s.json" % self.list.list_id, None)
     self.list.update("List One Renamed", "", False, "")
 
+  def test_update_with_unsubscribe_setting(self):
+    self.list.stub_request("lists/%s.json" % self.list.list_id, None)
+    self.list.update("List One Renamed", "", False, "", "OnlyThisList")
+
+  def test_update_with_unsubscribe_setting_and_supp_list_options(self):
+    self.list.stub_request("lists/%s.json" % self.list.list_id, None)
+    self.list.update("List One Renamed", "", False, "", "OnlyThisList", True, True)
+
   def test_delete(self):
     self.list.stub_request("lists/%s.json" % self.list.list_id, None)
     self.list.delete()
